---
title: Initializing Gramex Projects
prefix: Tip
...

Currently we can initialize projects using `yo gramex`. This needs additional `yeoman` installation and a supporting package.

This feature is now moved into gramex (v1.23) and we can initialize gramex projects using:

    :::shell
	gramex init

which will initialize files: index.html, config files (lint files, git files), gramex.yaml, package.json, README.md

**gramex.yaml**

`yaml` will be created with the following line

# Generated by gramex init on 2017-11-06 by Bhanu K <bhanu.kamapantula@gramener.com>. Please retain this line.

This will help us track the usage of `gramex init`.

Please use it and let us know if you have any feature requests or find bugs or any feedback.
